@@ -23,7 +23,7 @@ import itertools
 import collections
 
 __author__  = 'Miguel Turner'
-__version__ = '0.3.2'
+__version__ = '0.3.3'
 __license__ = 'MIT'
 
 __all__ = ['Config', 'IniFormat', 'ConfigError', 'Coercer', 'CoerceError']
@@ -40,6 +40,7 @@ if WIN:
         import winreg
     except ImportError:
         import _winreg as winreg
+    __all__.append('RegistryFormat')
 
 # the name *type* is used often so give type() an alias rather than use *typ*
 _type = type
@@ -173,11 +174,16 @@ class ConfigSection(collections.MutableMapping):
         
         If *type* is not provided, the type of the default value will be used.
         
+        If a value is already set for the section at *key*, it will be
+        coerced to *type*.
+        
         If a *comment* is provided, it may be written out to the config
         file in a manner consistent with the active :class:`~profig.Format`.
         """
         section = self._create_section(key)
         section._type = type or _type(default)
+        if section._value is not NoValue and _type(section._value) is not section._type:
+            section.convert(section._value)
         section.set_default(default)
         section.comment = comment
     
@@ -338,13 +344,17 @@ class ConfigSection(collections.MutableMapping):
     
     def convert(self, string):
         """str -> value"""
-        if not self._root.coercer:
-            value = string
-        else:
+        if self._root.coercer:
             type = self._type
-            if not (inspect.isclass(type) and issubclass(type, bytes)):
+            # if we are converting a byte-string and the type is not bytes,
+            # then we need to decode it
+            if isinstance(string, bytes) and not (
+                inspect.isclass(type) and issubclass(type, bytes)
+                ):
                 string = string.decode(self._root.encoding)
             value = self._root.coercer.convert(string, type)
+        else:
+            value = string
         self.set_value(value)
     
     ## utilities ##
