@@ -24,7 +24,7 @@ if profig.WIN:
         import _winreg as winreg
 
 class TestBasic(unittest.TestCase):
-    def test_init(self):
+    def test_initial_state(self):
         c = profig.Config()
 
         self.assertEqual(dict(c), {})
@@ -93,6 +93,54 @@ class TestBasic(unittest.TestCase):
         self.assertEqual(len(c), 1)
         self.assertEqual(len(c.section('a')), 1)
     
+    def test_init(self):
+        c = profig.Config()
+        c.init('a', 1)
+        c.init('a.a', 2)
+        
+        self.assertEqual(c['a'], 1)
+        
+        c['a'] = {'': 2, 'a': 3}
+        self.assertEqual(c['a'], 2)
+        self.assertEqual(c['a.a'], 3)
+        
+        s = c.section('a')
+        s.convert(b'3')
+        self.assertEqual(s.value(), 3)
+        self.assertEqual(s._value, 3)
+        self.assertIs(s._type, int)
+        self.assertIs(s.default(), 1)
+        self.assertIs(s._default, 1)
+    
+    def test_delayed_init(self):
+        c = profig.Config()
+        
+        c['a'] = {'': '2', 'a': '3'}
+        self.assertEqual(c['a'], '2')
+        self.assertEqual(c['a.a'], '3')
+        
+        s = c.section('a')
+        s.convert(b'3')
+        self.assertEqual(s.value(), '3')
+        self.assertEqual(s._value, '3')
+        self.assertIs(s._type, None)
+        self.assertIs(s._default, profig.NoValue)
+        with self.assertRaises(profig.NoValueError):
+            s.default()
+        
+        c.init('a', 1)
+        c.init('a.a', 2)
+        
+        self.assertEqual(c['a'], 3)
+        self.assertEqual(c['a.a'], 3)
+        
+        s = c.section('a')
+        self.assertEqual(s.value(), 3)
+        self.assertEqual(s._value, 3)
+        self.assertIs(s._type, int)
+        self.assertIs(s.default(), 1)
+        self.assertIs(s._default, 1)
+    
     def test_get(self):
         c = profig.Config()
         c['a'] = 1
@@ -216,7 +264,7 @@ class TestIniFormat(unittest.TestCase):
 
     def test_basic(self):
         del self.c['a.1']
-
+        
         buf = io.BytesIO()
         self.c.sync(buf)
         
@@ -517,12 +565,12 @@ if profig.WIN:
             c = self.c
             c.init('a', 1)
             c.init('a.a', 2)
-            c.init('c', u'str')
+            c.init('c', 'str')
             
             c.sync()
             
             k = winreg.OpenKeyEx(self.base_key, self.path)
-            self.assertEqual(winreg.QueryValueEx(k, 'c')[0], u'str')
+            self.assertEqual(winreg.QueryValueEx(k, 'c')[0], 'str')
             
             k = winreg.OpenKeyEx(k, 'a')
             self.assertEqual(winreg.QueryValueEx(k, '')[0], 1)
